const path = require('path');
const webpack = require('webpack');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const ExtractTextPlugin = require("extract-text-webpack-plugin");
const StyleLintPlugin = require('stylelint-webpack-plugin');
const StyleLintFormatter = require('stylelint-formatter-pretty');
const ChunkManifestPlugin = require('chunk-manifest-webpack-plugin');
const baseConfig = require('../config');
const baseRules = require('./baseRules.js');


const env = process.env;
const resolve = dir => path.resolve(__dirname, '..', dir);
env.NODE_ENV = env.NODE_ENV || 'dev';

const context = {
    env,
    pathPrefix: baseConfig.prod.pathPrefix,
    rootDir: resolve('./'),
}

module.exports = {
    entry: {
        app: resolve('src/entry-client.js'),
        vendors: [
            'react',
            'redux',
            'react-dom',
            'react-redux',
            'react-router',
            'prop-types',
        ],
    },

    output: {
        publicPath: baseConfig.client.publicPath,
        path: resolve(baseConfig.client.distPath),
        filename: '[name].[chunkhash:8].js',
    },

    resolve: {
        extensions: ['.js', '.jsx', '.json'],
        alias: {
            src: resolve('src'),
            conf: resolve('src/conf'),
            components: resolve('src/components'),
            layouts: resolve('src/layouts'),
            pages: resolve('src/pages'),
            routes: resolve('src/routes'),
            base: resolve('src/base'),
            modules: resolve('src/modules'),
            utils: resolve('src/utils'),
        },
    },

    module: {
        rules: [
            ...baseRules(context),
        ],

    },

    plugins: [
        new webpack.ProvidePlugin({
            React: 'react',
        }),

        new StyleLintPlugin({
            syntax: 'less',
            files: 'src/**/*.l?(e|c)ss',
            formatter: StyleLintFormatter,
        }),

        new ExtractTextPlugin({
            filename: `css/[name].[contenthash:8].css`
        }),

        new webpack.optimize.CommonsChunkPlugin({
            name: ['vendors', 'manifest'],
            minChunks: Infinity,
        }),
        new HtmlWebpackPlugin({
            filename: 'indexTemplate.html',
            template: 'src/index.html',
            hash: false,
            inject: true,
            minify: false,
        }),
    ],

    devServer: {
        port: baseConfig.dev.port,
        host: baseConfig.dev.host,
        proxy: baseConfig.dev.proxy,
    },
}
